@@ -18,15 +18,15 @@ import get_data_light
 
 # paths
 swd = tempfile.mkdtemp()
-data_dir = os.path.expanduser( os.path.join( '~', '.nipy', 'tests', 'data'))
-input_image = os.path.join( data_dir, 'spmT_0029.nii.gz')
-mask_image = os.path.join( data_dir, 'mask.nii.gz')
+data_dir = os.path.expanduser(os.path.join('~', '.nipy', 'tests', 'data'))
+input_image = os.path.join(data_dir, 'spmT_0029.nii.gz')
+mask_image = os.path.join(data_dir, 'mask.nii.gz')
 
-if os.path.exists(mask_image)==False or os.path.exists(input_image)==False:
-    get_data_light.get_it()
+if (not os.path.exists(mask_image)) or (not os.path.exists(input_image)):
+    get_data_light.get_second_level_dataset()
 
 # read the data
-mask = load(mask_image).get_data()>0
+mask = load(mask_image).get_data() > 0
 ijk = np.array(np.where(mask)).T
 nvox = ijk.shape[0]
 data = load(input_image).get_data()[mask]
@@ -40,4 +40,4 @@ label_image = os.path.join(swd, 'label.nii')
 wdata = mask - 1
 wdata[mask] = u
 save(Nifti1Image(wdata, load(mask_image).get_affine()), label_image)
-print "Label image written in %s"  % label_image
+print "Label image written in %s" % label_image
