@@ -3,9 +3,10 @@
 def configuration(parent_package='',top_path=None):
     from numpy.distutils.misc_util import Configuration
     config = Configuration('fixes', parent_package, top_path)
-
-    config.add_subpackage('*')
-
+    config.add_subpackage('sympy')
+    config.add_subpackage('sympy.utilities')
+    config.add_subpackage('numpy')
+    config.add_subpackage('numpy.testing')
     return config
 
 if __name__ == '__main__':
