@@ -19,7 +19,8 @@ Bertrand Thirion, 2009-2010
 """
 
 import numpy as np
-from nipy.labs.spatial_models.discrete_domain import grid_domain_from_array
+from nipy.labs.spatial_models.discrete_domain import \
+    grid_domain_from_binary_array
 
 # ---------------------------------------------------------
 # ----- cluster handling functions ------------------------
@@ -70,13 +71,13 @@ def cluster_threshold(stat_map, domain, th, csize):
     """
     if stat_map.shape[0] != domain.size:
         raise ValueError('incompatible dimensions')
-    
+
     # first build a domain of supra_threshold regions
     thresholded_domain = domain.mask(stat_map > th)
 
     # get the connected components
     label = thresholded_domain.connected_components()
-    
+
     binary = - np.ones(domain.size)
     binary[stat_map > th] = label
     nbcc = len(np.unique(label))
@@ -88,7 +89,7 @@ def cluster_threshold(stat_map, domain, th, csize):
     return binary
 
 
-def get_cluster_position_from_thresholded_map(stat_map, domain, thr=3.0, 
+def get_cluster_position_from_thresholded_map(stat_map, domain, thr=3.0,
                                               csize=10):
     """
     the clusters above thr of size greater than csize in
@@ -121,14 +122,14 @@ def get_cluster_position_from_thresholded_map(stat_map, domain, thr=3.0,
 
     # get the connected components
     label = thresholded_domain.connected_components()
-    
+
     # get the coordinates
     coord = thresholded_domain.get_coord()
 
     # get the barycenters
     baryc = []
     for i in range(label.max() + 1):
-        if np.sum(label==i) >= csize:
+        if np.sum(label == i) >= csize:
             baryc.append(np.mean(coord[label == i], 0))
 
     if len(baryc) == 0:
@@ -159,6 +160,7 @@ def get_peak_position_from_thresholded_map(stat_map, domain, threshold):
     # create an image to represent stat_map
     simage = domain.to_image(data=stat_map)
     
+    # extract the peaks
     peaks = get_3d_peaks(simage, threshold=threshold, order_th=2)
     if peaks == None:
         return None
@@ -310,7 +312,7 @@ def statistics_from_position(target, data, sigma=1.0):
                 1 is good
                 0 is bad
     """
-    from nipy.algorithms.routines.fast_distance import euclidean_distance as ed
+    from ...algorithms.utils.fast_distance import euclidean_distance as ed
     if data == None:
         if target == None:
             return 0.# could be 1.0 ?
@@ -660,7 +662,7 @@ def group_reproducibility_metrics(
     """
     from nibabel import load
     from ..mask import intersect_masks
-    
+
     if ((len(variance_images) == 0) & (method is not 'crfx')):
         raise ValueError('Variance images are necessary')
 
@@ -669,7 +671,7 @@ def group_reproducibility_metrics(
     # compute the group mask
     affine = load(mask_images[0]).get_affine()
     mask = intersect_masks(mask_images, threshold=0) > 0
-    domain = grid_domain_from_array(mask, affine)
+    domain = grid_domain_from_binary_array(mask, affine)
 
     # read the data
     group_con = []
@@ -733,7 +735,7 @@ def group_reproducibility_metrics(
 # -------------------------------------------------------
 
 
-def coord_bsa(domain, betas, theta=3., dmax=5., ths=0, thq=0.5, smin=0, 
+def coord_bsa(domain, betas, theta=3., dmax=5., ths=0, thq=0.5, smin=0,
               afname=None):
     """ main function for  performing bsa on a dataset
     where bsa =  nipy.labs.spatial_models.bayesian_structural_analysis
@@ -765,7 +767,7 @@ def coord_bsa(domain, betas, theta=3., dmax=5., ths=0, thq=0.5, smin=0,
     from ..spatial_models.bayesian_structural_analysis import compute_BSA_quick
 
     crmap, AF, BF, p = compute_BSA_quick(
-        domain, betas, dmax, thq, smin, ths, theta,  verbose=0)
+        domain, betas, dmax, thq, smin, ths, theta, verbose=0)
     if AF == None:
         return None
     if afname is not None:
