@@ -5,9 +5,14 @@ Matplotlib colormaps useful for neuroimaging.
 """
 import numpy as _np
 
-from matplotlib import cm as _cm
-from matplotlib import colors as _colors
+from nipy.utils.skip_test import skip_if_running_nose
 
+try:
+    from matplotlib import cm as _cm
+    from matplotlib import colors as _colors
+except ImportError:
+    skip_if_running_nose('Could not import matplotlib')
+ 
 ################################################################################
 # Custom colormaps for two-tailed symmetric statistics
 ################################################################################
@@ -52,6 +57,40 @@ def _pigtailed_cmap(cmap, swap_order=('green', 'red', 'blue')):
     return cdict
 
 
+def _concat_cmap(cmap1, cmap2):
+    """ Utility function to make a new colormap by concatenating two
+        colormaps.
+    """
+    cdict = dict()
+
+    cdict1 = cmap1._segmentdata.copy()
+    cdict2 = cmap2._segmentdata.copy()
+    if not callable(cdict1['red']):
+        for c in ['red', 'green', 'blue']:
+            cdict[c] = [(0.5*p, c1, c2) for (p, c1, c2) in cdict1[c]]
+    else:
+        for c in ['red', 'green', 'blue']:
+            cdict[c] = []
+        ps = _np.linspace(0, 1, 10)
+        colors = cmap1(ps)
+        for p, (r, g, b, a) in zip(ps, colors):
+            cdict['red'].append((.5*p, r, r))
+            cdict['green'].append((.5*p, g, g))
+            cdict['blue'].append((.5*p, b, b))
+    if not callable(cdict2['red']):
+        for c in ['red', 'green', 'blue']:
+            cdict[c].extend([(0.5*(1+p), c1, c2) for (p, c1, c2) in cdict2[c]])
+    else:
+        ps = _np.linspace(0, 1, 10)
+        colors = cmap2(ps)
+        for p, (r, g, b, a) in zip(ps, colors):
+            cdict['red'].append((.5*(1+p), r, r))
+            cdict['green'].append((.5*(1+p), g, g))
+            cdict['blue'].append((.5*(1+p), b, b))
+
+    return cdict
+
+
 def alpha_cmap(color, name=''):
     """ Return a colormap with the given color, and alpha going from
         zero to 1.
@@ -79,7 +118,6 @@ def alpha_cmap(color, name=''):
 
 ################################################################################
 # Our colormaps definition
-
 _cmaps_data = dict(
     cold_hot     = _pigtailed_cmap(_cm.hot),
     brown_blue   = _pigtailed_cmap(_cm.bone),
@@ -103,6 +141,14 @@ _cmaps_data = dict(
     black_red    = _cm.hot._segmentdata.copy(),
 )
 
+if hasattr(_cm, 'ocean'):
+    # MPL 0.99 doesn't have Ocean
+    _cmaps_data['ocean_hot'] =  _concat_cmap(_cm.ocean, _cm.hot_r)
+if hasattr(_cm, 'afmhot'): # or afmhot
+    _cmaps_data['hot_white_bone'] = _concat_cmap(_cm.afmhot, _cm.bone_r)
+    _cmaps_data['hot_black_bone'] = _concat_cmap(_cm.afmhot_r, _cm.bone)
+
+
 ################################################################################
 # Build colormaps and their reverse.
 _cmap_d = dict()
@@ -133,7 +179,7 @@ for _cmapname in _cmaps_data.keys():
 for color, name in (((1, 0, 0), 'red'),
                     ((0, 1, 0), 'blue'),
                     ((0, 0, 1), 'green'),
-                      ):
+                    ):
     _cmap_d['%s_transparent' % name] = alpha_cmap(color, name=name)
 
 
