@@ -1,5 +1,4 @@
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
-vmax = None
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 """
 The OrthoSlicer class.
@@ -7,30 +6,27 @@ The OrthoSlicer class.
 The main purpose of this class is to have auto adjust of axes size to
 the data.
 """
-import warnings
 
 import numpy as np
-from scipy import ndimage, signal
+from nipy.utils.skip_test import skip_if_running_nose
 
-import pylab as pl
-import matplotlib as mp
-from matplotlib.transforms import Bbox
+try:
+    import matplotlib as mpl
+    import pylab as pl
+    from matplotlib import transforms
+except ImportError:
+    skip_if_running_nose('Could not import matplotlib')
+    
 
 # Local imports
 from .coord_tools import coord_transform, get_bounds, get_mask_bounds
+from .edge_detect import _edge_map
 from . import cm
 from ..datasets import VolumeImg
 
-try:
-    # Protect this import as it is compiled code
-    from nipy.labs.utils.routines import quantile
-except ImportError, e:
-    warnings.warn('Could not import fast quantile function: %s' % e)
-    quantile = None
-
 ################################################################################
 # Bugware to have transparency work OK with MPL < .99.1
-if mp.__version__ < '0.99.1':
+if mpl.__version__ < '0.99.1':
     # We wrap the lut as a callable and replace its evalution to put
     # alpha to zero where the mask is true. This is what is done in 
     # MPL >= .99.1
@@ -59,130 +55,6 @@ def _xyz_order(map, affine):
     map = img.get_data()
     affine = img.affine
     return map, affine
-                    
-################################################################################
-# Edge detection
-
-def _fast_abs_percentile(map, percentile=80):
-    """ A fast version of the percentile of the absolute value.
-    """
-    if hasattr(map, 'mask'):
-        map = np.asarray(map[np.logical_not(map.mask)])
-    map = np.abs(map)
-    map = map.ravel()
-    if quantile is not None:
-        return quantile(map, .01*percentile)
-    map.sort()
-    nb = map.size
-    return map[.01*percentile*nb]
-
-
-def _orientation_kernel(t):
-    """ structure elements for calculating the value of neighbors in several 
-        directions
-    """ 
-    sin = np.sin
-    pi  = np.pi
-    t = pi*t
-    arr =  np.array([[sin(t),        sin(t+.5*pi),  sin(t+pi)    ],
-                     [sin(t+1.5*pi), 0,             sin(t+1.5*pi)],
-                     [sin(t+pi),     sin(t+.5*pi),  sin(t)       ]])
-    return np.round(.5*((1+arr))**2).astype(np.bool)
-
-
-def _edge_detect(image, high_threshold=.75, low_threshold=.4):
-    """ Edge detection for 2D images based on Canny filtering.
-
-        Parameters
-        ==========
-        image: 2D array
-            The image on which edge detection is applied
-        high_threshold: float, optional
-            The quantile defining the upper threshold of the hysteries 
-            thresholding: decrease this to keep more edges
-        low_threshold: float, optional
-            The quantile defining the lower threshold of the hysteries 
-            thresholding: decrease this to extract wider edges
-
-        Returns
-        ========
-        grad_mag: 2D array of floats
-            The magnitude of the gradient
-        edge_mask: 2D array of booleans
-            A mask of where have edges been detected
-
-        Notes
-        ======
-        This function is based on a Canny filter, however it has been
-        taylored to visualization purposes on brain images: don't use it
-        in the general case.
-
-        It computes the norm of the gradient, extracts the ridge by
-        keeping only local maximum in each direction, and performs
-        hysteresis filtering to keep only edges with high gradient
-        magnitude.
-    """
-    # This code is loosely based on code by Stefan van der Waalt
-    # Convert to floats to avoid overflows
-    np_err = np.seterr(all='ignore')
-    img = signal.wiener(image.astype(np.float))
-    np.seterr(**np_err)
-    # Where the noise variance is 0, Wiener can create nans
-    img[np.isnan(img)] = image[np.isnan(img)]
-    img /= img.max()
-    grad_x = ndimage.sobel(img, mode='constant', axis=0)
-    grad_y = ndimage.sobel(img, mode='constant', axis=1)
-    grad_mag = np.sqrt(grad_x**2 + grad_y**2)
-    grad_angle = np.arctan2(grad_y, grad_x)
-    # Scale the angles in the range [0, 2]
-    grad_angle = (grad_angle + np.pi) / np.pi
-    # Non-maximal suppression: an edge pixel is only good if its magnitude is
-    # greater than its neighbors normal to the edge direction.
-    thinner = np.zeros(grad_mag.shape, dtype=np.bool)
-    for angle in np.arange(0, 2, .25):
-        thinner = thinner | (
-                (grad_mag > .85*ndimage.maximum_filter(grad_mag,
-                                    footprint=_orientation_kernel(angle))) 
-                & (((grad_angle - angle) % 2) < .75)
-               )
-    # Remove the edges next to the side of the image: they are not reliable
-    thinner[0]     = 0
-    thinner[-1]    = 0
-    thinner[:, 0]  = 0
-    thinner[:, -1] = 0
-
-    thinned_grad = thinner * grad_mag
-    # Hysteresis thresholding: find seeds above a high threshold, then
-    # expand out until we go below the low threshold
-    grad_values = thinned_grad[thinner]
-    high = thinned_grad > _fast_abs_percentile(grad_values, 100*high_threshold)
-    low = thinned_grad >  _fast_abs_percentile(grad_values, 100*low_threshold)
-    edge_mask = ndimage.binary_dilation(high, structure=np.ones((3, 3)), 
-                                        iterations=-1, mask=low)
-    return grad_mag, edge_mask
-
-
-def _edge_map(image):
-    """ Return a maps of edges suitable for visualization.
-
-        Parameters
-        ==========
-        image: 2D array
-            The image that the edges are extracted from.
-
-        Returns
-        ========
-        edge_mask: 2D masked array
-            A mask of the edge as a masked array with parts without
-            edges masked and the large extents detected with lower
-            coefficients.
-    """
-    edge_mask = _edge_detect(image)[-1]
-    edge_mask = edge_mask.astype(np.float)
-    edge_mask = -np.sqrt(ndimage.distance_transform_cdt(edge_mask))
-    edge_mask[edge_mask != 0] -= -.05+edge_mask.min()
-    edge_mask = np.ma.masked_less(edge_mask, .01)
-    return edge_mask
 
 ################################################################################
 # class OrthoSlicer
@@ -231,13 +103,14 @@ class OrthoSlicer(object):
         axes.set_zorder(1)
         bb = axes.get_position()
         self.rect = (bb.x0, bb.y0, bb.x1, bb.y1)
+        x0, y0, x1, y1 = self.rect
         self._object_bounds = dict()
         self._black_bg = black_bg
 
         # Create our axes:
         self.axes = dict()
         for index, name in enumerate(('x', 'y', 'z')):
-            ax = pl.axes([0.3*index, 0, .3, 1])
+            ax = pl.axes([0.3*index*(x1-x0) + x0, y0, .3*(x1-x0), y1-y0])
             ax.axis('off')
             self.axes[name] = ax
             ax.set_axes_locator(self._locator)
@@ -275,8 +148,8 @@ class OrthoSlicer(object):
         left_dict[x_ax] = x0
         left_dict[y_ax] = x0 + width_dict[x_ax]
         left_dict[z_ax] = x0 + width_dict[x_ax] + width_dict[y_ax]
-        return Bbox([[left_dict[axes], 0], 
-                     [left_dict[axes] + width_dict[axes], 1]])
+        return transforms.Bbox([[left_dict[axes], y0], 
+                          [left_dict[axes] + width_dict[axes], y1]])
 
 
     def draw_cross(self, cut_coords=None, **kwargs):
@@ -495,7 +368,7 @@ class OrthoSlicer(object):
         map, affine = _xyz_order(map, affine)
         # Force the origin
         kwargs['origin'] = 'upper'
-        if mp.__version__ < '0.99.1':
+        if mpl.__version__ < '0.99.1':
             cmap = kwargs.get('cmap', 
                         pl.cm.cmap_d[pl.rcParams['image.cmap']])
             kwargs['cmap'] = CMapProxy(cmap)
@@ -563,7 +436,7 @@ class OrthoSlicer(object):
         # Force the origin
         kwargs = dict(cmap=cm.alpha_cmap(color=color))
         kwargs['origin'] = 'upper'
-        if mp.__version__ < '0.99.1':
+        if mpl.__version__ < '0.99.1':
             cmap = kwargs.get('cmap', 
                         pl.cm.cmap_d[pl.rcParams['image.cmap']])
             kwargs['cmap'] = CMapProxy(cmap)
