@@ -2,12 +2,11 @@
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 """The testing directory contains a small set of imaging files to be
 used for doctests only.  More thorough tests and example data will be
-stored in a nipy data packages that you can download separately - see
-:mod:`nipy.utils.data`
+stored in a nipy data packages that you can download separately.
 
 .. note:
 
-   We use the ``nose`` testing framework for tests.  
+   We use the ``nose`` testing framework for tests.
 
    Nose is a dependency for the tests, but should not be a dependency
    for running the algorithms in the NIPY library.  This file should
@@ -36,7 +35,12 @@ funcfile = os.path.join(basedir, 'functional.nii.gz')
 anatfile = os.path.join(basedir, 'anatomical.nii.gz')
 
 from numpy.testing import *
-import decorators as dec
+# Overwrites numpy.testing.Tester
+from .nosetester import NipyNoseTester as Tester
+test = Tester().test
+bench = Tester().bench
+
+from . import decorators as dec
 
 # Allow failed import of nose if not now running tests
 try:
